# Dataset Grouper

Dataset Grouper is a library for creating, writing, and iterating over datasets
with group-level structure. It is primarily intended for creating datasets useful
for federated learning research, and prioritizes flexibility and scalability.

### Disclaimers

This is a utility library that downloads and prepares public datasets. We do
not host or distribute these datasets, vouch for their quality or fairness, or
claim that you have license to use the dataset. It is your responsibility to
determine whether you have permission to use the dataset under the dataset's
license.

If you're interested in learning more about responsible AI practices, please
see Google AI's [Responsible AI Practices](https://ai.google/education/responsible-ai-practices).

Dataset Grouper is Apache 2.0 licensed. See the [`LICENSE`](LICENSE) file.

This is not an officially supported Google product.
